import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { DetailedFilterSegment } from '../models/detailed-filter-segment';
import { FilterSegmentNamespaceDto } from '../models/filter-segment-namespace-dto';
import { FilterSegments } from '../models/filter-segments';
import { LeanFilterSegments } from '../models/lean-filter-segments';
import { NewFilterSegment } from '../models/new-filter-segment';
import { PartialUpdateFilterSegment } from '../models/partial-update-filter-segment';
import { UpdateFilterSegment } from '../models/update-filter-segment';
import { ApiClientOptions } from './api-client-options';
export declare class FilterSegmentsClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a FilterSegmentsClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const filterSegmentsClientNodeJs = new FilterSegmentsClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * Get filter-segment by UID.
     *
     * Get filter-segment by its UID.
     *
     * Required scopes:
     *
     * - `storage:filter-segments:read`
     *
     * @returns {Promise<DetailedFilterSegment>} Filter-segment successfully retrieved.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data = await filterSegmentsClient.getFilterSegment({
     *   filterSegmentUid: "D82a1jdA23a",
     * });
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions | Not found: the server cannot find the requested filter-segment.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getFilterSegment(config: {
        /** UID of the filter-segment */ filterSegmentUid: string;
        /** Add additional fields. */ addFields?: ('INCLUDES' | 'VARIABLES' | 'EXTERNALID' | 'RESOURCECONTEXT')[];
        abortSignal?: AbortSignal;
    }): Promise<DetailedFilterSegment>;
    /**
     * Update a filter-segment. All fields will be overwritten (also undefined or null fields).
     *
     * Update one or more fields of a filter-segment.
     *
     * Required scopes:
     * - `storage:filter-segments:write`
     * - `storage:filter-segments:share` to change `isPublic` to `true`
     *
     * Following fields can be updated:
     *
     * - `name`
     * - `description`
     * - `isPublic`
     * - `variables`*
     * - `includes`*
     *
     * \* Values of the fields will be overridden or removed if not given.
     *
     * Provide all other fields with unchanged values.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data = await filterSegmentsClient.updateFilterSegment(
     *   {
     *     filterSegmentUid: "D82a1jdA23a",
     *     optimisticLockingVersion: 1,
     *     body: {
     *       uid: "D82a1jdA23a",
     *       name: "dev_environment",
     *       description:
     *         "only includes data of the development environment",
     *       variables: {
     *         type: "query",
     *         value: "fetch logs | limit 1",
     *       },
     *       isPublic: false,
     *       owner: "john.doe",
     *       includes: [
     *         {
     *           filter:
     *             '{"type":"Group","range":{"from":0,"to":19},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":19},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[debug]\\"","value":"[debug]","range":{"from":10,"to":19},"isEscaped":true}}]}',
     *           dataObject: "logs",
     *         },
     *         {
     *           filter:
     *             '{"type":"Group","range":{"from":0,"to":18},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":18},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[info]\\"","value":"[info]","range":{"from":10,"to":18},"isEscaped":true}}]}',
     *           dataObject: "events",
     *         },
     *       ],
     *     },
     *   },
     * );
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions | Not found: the server cannot find the requested filter-segment.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    updateFilterSegment(config: {
        body: UpdateFilterSegment;
        /** UID of the filter-segment */ filterSegmentUid: string;
        /** version which should be updated. used for optimistic locking. */ optimisticLockingVersion: number;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Delete a filter-segment.
     *
     * Remove the filter-segment from the environment for all users.
     *
     * Required scopes:
     * - `storage:filter-segments:delete`
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data = await filterSegmentsClient.deleteFilterSegment(
     *   { filterSegmentUid: "D82a1jdA23a" },
     * );
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions | Not found: the server cannot find the requested filter-segment.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteFilterSegment(config: {
        /** UID of the filter-segment */ filterSegmentUid: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Partially update a filter-segment.
     *
     * Update one or more fields of a filter-segment.
     *
     * Required scopes:
     * - `storage:filter-segments:write`
     * - `storage:filter-segments:share` to change `isPublic` to `true`
     *
     * Following fields can be updated:
     *
     * - `name`
     * - `description`
     * - `isPublic`
     * - `variables`*
     * - `includes`*
     *
     * \* If given the value will be overridden.
     *
     * Fields not given will be ignored.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data =
     *   await filterSegmentsClient.partiallyUpdateFilterSegment({
     *     filterSegmentUid: "D82a1jdA23a",
     *     optimisticLockingVersion: 1,
     *     body: {
     *       description:
     *         "only includes data of the development environment",
     *     },
     *   });
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions | Not found: the server cannot find the requested filter-segment.
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    partiallyUpdateFilterSegment(config: {
        body: PartialUpdateFilterSegment;
        /** UID of the filter-segment */ filterSegmentUid: string;
        /** version which should be updated. used for optimistic locking. */ optimisticLockingVersion: number;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * Get all filter-segments.
     *
     * Returns all filter-segments.
     * If details like description are not needed then consider using the `:lean` endpoint.
     *
     * Required scopes:
     *
     * - `storage:filter-segments:read`
     *
     * @returns {Promise<FilterSegments>} Filter-segments successfully retrieved.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data = await filterSegmentsClient.getFilterSegments();
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getFilterSegments(config?: {
        /** Add additional fields. */ addFields?: ('VARIABLES' | 'EXTERNALID' | 'RESOURCECONTEXT')[];
        abortSignal?: AbortSignal;
    }): Promise<FilterSegments>;
    /**
     * Create a new filter-segment.
     *
     * Create a new segment and define data.
     *
     * Required scopes:
     *
     * - `storage:filter-segments:write`
     * - `storage:filter-segments:share` if `isPublic` is set to `true`
     *
     * ### New Filter-Segment
     *
     * Provide a name and an optional description for the filter-segment.
     *
     * #### Variables
     *
     * Create variables to apply in your filter-segment data filters
     *
     * #### Includes (Segment data)
     *
     * Include all data that should be accessible when applying the filter-segment
     *
     * #### IsPublic (Visibility)
     *
     * - `false`: The filter-segment is private and only visible to the owner
     * - `true`: The filter-segment is visible to everyone in the environment
     *
     * @returns {Promise<DetailedFilterSegment>} Filter-segment successfully created.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data = await filterSegmentsClient.createFilterSegment(
     *   {
     *     body: {
     *       name: "dev_environment",
     *       description:
     *         "only includes data of the dev environment",
     *       variables: {
     *         type: "query",
     *         value: "fetch logs | limit 1",
     *       },
     *       isPublic: false,
     *       includes: [
     *         {
     *           filter:
     *             '{"type":"Group","range":{"from":0,"to":19},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":19},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[debug]\\"","value":"[debug]","range":{"from":10,"to":19},"isEscaped":true}}]}',
     *           dataObject: "logs",
     *         },
     *         {
     *           filter:
     *             '{"type":"Group","range":{"from":0,"to":18},"logicalOperator":"AND","explicit":false,"children":[{"type":"Statement","range":{"from":0,"to":18},"key":{"type":"Key","textValue":"content","value":"content","range":{"from":0,"to":7}},"operator":{"type":"ComparisonOperator","textValue":"=","value":"=","range":{"from":8,"to":9}},"value":{"type":"String","textValue":"\\"[info]\\"","value":"[info]","range":{"from":10,"to":18},"isEscaped":true}}]}',
     *           dataObject: "events",
     *         },
     *       ],
     *     },
     *   },
     * );
     *
     * @throws {ErrorEnvelopeError} Filter-segment Bad Request. | unauthorized | missing permissions
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    createFilterSegment(config: {
        body: NewFilterSegment;
        abortSignal?: AbortSignal;
    }): Promise<DetailedFilterSegment>;
    /**
     * Get all filter-segments in a minimal/lean form.
     *
     * Returns all filter-segments in a minimal representational form. This endpoint saves resources
     * and as a result quicker response times can be expected over the more detailed get-all
     * endpoint.
     *
     * Required scopes:
     *
     * - `storage:filter-segments:read`
     *
     * @returns {Promise<LeanFilterSegments>} Filter-segments successfully retrieved.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data =
     *   await filterSegmentsClient.getLeanFilterSegments();
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getLeanFilterSegments(config?: {
        /** Add additional fields. */ addFields?: ('VARIABLES' | 'EXTERNALID' | 'RESOURCECONTEXT' | 'OWNER')[];
        abortSignal?: AbortSignal;
    }): Promise<LeanFilterSegments>;
    /**
     * Get filter-segment-entity-model.
     *
     * Returns the filter-segment-entity-model.
     *
     * Required scopes:
     *
     * - `storage:filter-segments:read`
     *
     * @returns {Promise<FilterSegmentNamespaceDto>} Filter-segments-entity-model successfully retrieved.
     *
     * @example <caption>Code example</caption>
     * import { filterSegmentsClient } from "@dynatrace-sdk/client-filter-segment-management";
     *
     * const data =
     *   await filterSegmentsClient.getFilterSegmentsEntityModel();
     *
     * @throws {ErrorEnvelopeError} bad request | unauthorized | missing permissions
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getFilterSegmentsEntityModel(config?: {
        abortSignal?: AbortSignal;
    } | AbortSignal): Promise<FilterSegmentNamespaceDto>;
}
export declare const filterSegmentsClient: FilterSegmentsClient;
